@@ -9,6 +9,7 @@ extern  GtkWidget	*sleep_enable;
 extern  GtkWidget	*sleep_idle_spin;
 extern  GtkWidget	*dim_enable;
 extern  GtkWidget	*dim_spin;
+extern  GtkWidget	*dim_scale;
 extern  GtkWidget	*sleep_apm;
 extern  GtkWidget	*sleep_cpu;
 extern  GtkWidget	*sleep_cpu_spin;
@@ -34,6 +35,11 @@ void set_conf_defaults(GtkWidget *top, ipaq_conf_t *conf)
   gtk_range_set_value(GTK_RANGE(wgt), (gfloat)ival);
   gtk_widget_set_sensitive(wgt, (ival > 0));
 
+  ival = getConfigInt(conf, "dim_level");
+  wgt = dim_scale;
+  gtk_range_set_value(GTK_RANGE(wgt), (gfloat)ival);
+  gtk_widget_set_sensitive(wgt, (ival > 0));
+  
   wgt = sleep_apm;
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wgt), getConfigInt(conf, "check_apm"));  
 
