@@ -34,7 +34,9 @@
 #include "cfgfile.h"
 #include "ownerinfo.h"
 #include "ipaqscreen/brightness.h"
+#ifndef DISABLE_XRANDR
 #include "ipaqscreen/rotation.h"
+#endif
 #ifdef PACKAGETOOL		
 #include "packages.h"
 #include "keyboard.h"
@@ -42,6 +44,7 @@
 #include "serial.h"
 #include "cardinfo.h"
 #include "timeanddate.h"
+#include "users/passwd.h"
 
 static GtkWidget *passwd_entry;
 static int retv;
@@ -66,13 +69,14 @@ update_screen_brightness (int br)
 	set_brightness (br);
 }
 
+#ifndef DISABLE_XRANDR
 void
 update_screen_rotation (int rotation)
 {
 	if ((rotation >= 0) && (rotation <= 3))
 		set_rotation (rotation);
 }
-
+#endif
 
 void
 update_dns_server (const gchar * server)
@@ -283,6 +287,10 @@ check_user_access (const char *cmd)
 	if (!strcmp (cmd, "NTPD"))
 		return TRUE;
 	
+	/* allow changing password */
+	if (!strcmp (cmd, "CHPW"))
+		return TRUE;
+	
 	return global_user_access;
 }
 
@@ -312,7 +320,6 @@ suidloop (int write, int read)
 		cmd[0] = ' ';
 		fflush (stdout);
 		fscanf (in, "%4s\n%s\n", cmd, passwd);
-		//    if (!feof (in))
 		{
 			cmd[4] = 0;
 			bin = NULL;
@@ -345,8 +352,7 @@ suidloop (int write, int read)
 					strcpy (arg1, "/tmp/passwd");
 					strcpy (arg2, "/etc/passwd");
 					numarg = 2;
-					system_printf ("/bin/cp %s %s", arg1,
-						       arg2);
+					system_printf ("/bin/cp %s %s", arg1, arg2);
 					system_printf ("chmod 0644 %s", arg2);
 					system_printf ("/bin/rm -f %s", arg1);
 				}
@@ -411,11 +417,13 @@ suidloop (int write, int read)
 					fscanf (in, "%d", &numarg);
 					update_screen_brightness (numarg);
 				}
+#ifndef DISABLE_XRANDR
 				else if (strcmp (cmd, "SCRR") == 0)  // rotate screen
 				{
 					fscanf (in, "%d", &numarg);
 					update_screen_rotation (numarg);
 				}
+#endif				
 				else if (strcmp (cmd, "CRHD") == 0)  // create a users home directory
 				{
 					fscanf (in, "%100s", arg1);	// directory
@@ -513,6 +521,18 @@ suidloop (int write, int read)
 					system (cmd);
 					g_free(cmd);
 				}
+				else if (strcmp (cmd, "CHPW") == 0)  // change users password
+				{
+					struct passwd *pw;
+					
+					fscanf (in, "%100s %128s", arg2, arg1);
+					/* empty password */
+					if (!strcmp(arg1, "*"))
+						memset(arg1, 0, sizeof(arg1));
+					pw = getpwnam(arg2);
+					if (pw)
+						update_passwd (pw, arg1);
+				}
 			}	// if check_user_access
 			else	// clear buffer
 			{
